@@ -4,7 +4,7 @@ use utf8;
 use strict;
 use warnings;
 
-$Acme::Glue::VERSION = "2023.07";
+$Acme::Glue::VERSION = "2023.08";
 
 =encoding utf8
 
@@ -14,7 +14,7 @@ Acme::Glue - A placeholder module for code accompanying a Perl photo project
 
 =head1 VERSION
 
-2023.07
+2023.08
 
 =head1 DESCRIPTION
 
@@ -33,7 +33,7 @@ are shot at.
 
 =head1 SNIPPETS
 
-Here are the snippets that accompany the photo project
+Here are the snippets that may accompany the photo project
 
 =head2 LEEJO (transform.pl)
 
@@ -129,6 +129,17 @@ Here are the snippets that accompany the photo project
        16254 ./regcomp.c
        15712 ./op.c
 
+=head2 MIKESTOK (soundex "joke")
+
+    sub Soundex
+    {
+      local ($_, $f) = shift;
+
+      y;a-z;A-Z;;y;A-Z;;cd;$_ ne q???do{($f)=m;^(.);;s;$f+;;;
+      y;AEHIOUWYBFPVCGJKQSXZDTLMNR;00000000111122222222334556;;
+      y;;;cs;y;0;;d;s;^;$f;;s;$;0000;;m;(^.{4});;$1;}:q;;;
+    }
+
 =head2 SLU (MAZE.BAS)
 
     10 PRINT CHR$(205.5+RND(1));:GOTO 10
